---
title: <span class="badge object-type-scalar"></span> KilobitsPerSecond
---
# <span class="badge object-type-scalar"></span> KilobitsPerSecond

Data rate: kilobits/sec

## Definition

```python
# Data rate: kilobits/sec
KilobitsPerSecond: typing.Literal["Kbits"] = "Kbits"
```
